package com.couplet.analyze.msg.model;

import com.couplet.analyze.common.event.AnalyzeEventCache;
import com.couplet.analyze.msg.domain.CoupletMsgData;
import com.couplet.analyze.msg.service.IncidentService;
import com.couplet.common.core.exception.vehicle.VehicleException;
import com.couplet.common.core.utils.SpringUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.consumer.ConsumerConfig;
import org.apache.kafka.clients.consumer.ConsumerRecords;
import org.apache.kafka.clients.consumer.KafkaConsumer;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.time.Duration;
import java.util.Collections;
import java.util.List;
import java.util.Properties;
import java.util.Set;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

import static com.couplet.analyze.msg.utils.MsgUtils.hexToString;
import static com.couplet.analyze.msg.utils.MsgUtils.sendMsg;
import static java.lang.Thread.sleep;


/**
 * @author DongXiaoDong
 * @version 1.0
 * @date 2024/4/6 14:04
 * @description
 */
@Component
@Slf4j
public class ModelsKafkaMessage {
    private static final String TOPIC_NAME = "lyh";
    private static final String BOOTSTRAP_SERVERS = "39.103.133.136:9092";


    //线程池，用于异步处理消息到来时的业务逻辑
    private ExecutorService executorService = Executors.newSingleThreadExecutor();

    //kafka消费者实例化为类成员变量
    KafkaConsumer<String, String> consumer;

    @Autowired
    private AnalyzeEventCache analyzeEventCache;


    //kafka消费者初始化
    @PostConstruct
    public void initKafkaConsumer() {
        Properties props = new Properties();
        props.put(ConsumerConfig.BOOTSTRAP_SERVERS_CONFIG, BOOTSTRAP_SERVERS);
//        props.put(ConsumerConfig.GROUP_ID_CONFIG, "my-consumer-group");
        props.put(ConsumerConfig.GROUP_ID_CONFIG, "lll");
        props.put(ConsumerConfig.KEY_DESERIALIZER_CLASS_CONFIG, "org.apache.kafka.common.serialization.StringDeserializer");
        props.put(ConsumerConfig.VALUE_DESERIALIZER_CLASS_CONFIG, "org.apache.kafka.common.serialization.StringDeserializer");

        //消费者
        consumer = new KafkaConsumer<>(props);
        //订阅主题
        consumer.subscribe(Collections.singletonList(TOPIC_NAME));
    }



    /**
     * 消费者配置
     *
     * @return
     */
//    @Scheduled(fixedDelay = 50)
    @PostConstruct
    public void consumerMessages() {
        executorService.execute(this::consumer);
    }

    public void consumer() {
        try {

            //持续消费消息
            while (true) {
                ConsumerRecords<String, String> records = consumer.poll(Duration.ofMillis(100));
                records.forEach(record -> {
                    System.out.println("接收到的数据：" + record.value());
                    String str = hexToString(record.value());
                    List<CoupletMsgData> coupletMsgDataList = sendMsg(str);
                    for (CoupletMsgData msgData : coupletMsgDataList) {
                        log.info("解析到车辆数据：{}", msgData);
                        Set<String> eventList = analyzeEventCache.getEventList(msgData.getVin());
                        for (String string : eventList) {
                            IncidentService incidentService = SpringUtils.getBean(string);
                            incidentService.incident(msgData);
                        }
                        //  发送消息
//                        rabbitTemplate.convertAndSend("couplet-code-queue",msgData,message -> {
//                            message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
//                            return message;
//                        });
                    }
                });
            }
        } catch (Exception e) {
            log.error(e.getMessage());
        }
    }

}
