package com.couplet.analyze.msg.service.impl;

import com.alibaba.fastjson.JSON;
import com.couplet.analyze.common.contents.AnalyzeEventContents;
import com.couplet.analyze.msg.contents.StateConstant;
import com.couplet.analyze.msg.domain.CoupletMsgData;
import com.couplet.analyze.msg.service.IncidentService;
import com.couplet.analyze.msg.utils.MsgUtils;
import com.couplet.common.domain.CoupletTroubleCode;
import com.couplet.common.redis.service.RedisService;
import com.couplet.remote.RemoteTroubleService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.listener.KeyExpirationEventMessageListener;
import org.springframework.data.redis.listener.RedisMessageListenerContainer;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.HashSet;
import java.util.Set;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.TimeUnit;

/**
 * @Author: LiJiaYao
 * @Date: 2024/4/2
 * @Description: 故障事件
 */
@Service(AnalyzeEventContents.BREAKDOWN)
public class BreakdownServiceImpl extends KeyExpirationEventMessageListener implements IncidentService {

    /**
     * 设置redis存储
     */
    @Autowired
    private RedisService redisService;
    @Autowired
    private RemoteTroubleService remoteTroubleService;


    private static Logger log = LoggerFactory.getLogger(BreakdownServiceImpl.class);

    public BreakdownServiceImpl(RedisMessageListenerContainer listenerContainer) {
        super(listenerContainer);
    }


    /**
     * 故障事件
     *
     * @param coupletMsgData
     */
    @Override
    public void incident(CoupletMsgData coupletMsgData) {

        log.info("故障事件开始.....");
        long l = System.currentTimeMillis();
        log.info("开始时间是："+l);
        if (StateConstant.VEHICLE_STATUS != coupletMsgData.getVehicleStatus()
                || StateConstant.CHARGING_STATUS!=coupletMsgData.getChgStatus()
                || StateConstant.OPERATING_STATUS!=coupletMsgData.getOperatingStatus()
                || StateConstant.SOC_STATUS!=coupletMsgData.getSocStatus()
                || StateConstant.CHARGING_ENERGY_STORAGE_STATUS != coupletMsgData.getChargingEnergyStorageStatus()
                || StateConstant.DRIVE_MOTOR_STATUS != coupletMsgData.getDriveMotorStatus()
                || StateConstant.POSITION_STATUS != coupletMsgData.getPositionStatus()
                || StateConstant.EAS_STATUS != coupletMsgData.getEasStatus()
                || StateConstant.PTC_STATUS != coupletMsgData.getPtcStatus()
                || StateConstant.ABS_STATUS != coupletMsgData.getAbsStatus()
                || StateConstant.MCU_STATUS != coupletMsgData.getMcuStatus()
                || StateConstant.HEATING_STATUS != coupletMsgData.getHeatingStatus()
                || StateConstant.BATTERY_STATUS != coupletMsgData.getBatteryStatus()
                || StateConstant.BATTERY_INSULATION_STATUS != coupletMsgData.getBatteryInsulationStatus()
                || StateConstant.DCDC_STATUS != coupletMsgData.getDcdcStatus()
                || StateConstant.CHG_STATUS != coupletMsgData.getChgStatus()){
                //获取过期的key
            String key = "breakdown";
            log.debug("失效+key is:"+ key);
            redisService.setCacheSet(key, coupletMsgData);
            long expireTime = 30;
            redisService.expire(key, expireTime, TimeUnit.MINUTES);
            scheduledRedis();
            long timeMillis = System.currentTimeMillis();
            log.info("故障事件结束时间："+timeMillis);
            log.info("故障事件检测结束.....");
        }
        long timeMillis = System.currentTimeMillis();
        log.info("故障事件结束时间："+timeMillis);
        log.info("故障事件结束.....");
    }

    /**
     * @return 获取事件名称
     */
    @Override
    public String getName() {
        return AnalyzeEventContents.BREAKDOWN;
    }

    public void scheduledRedis() {
        // Get all members of the set
        String key = "breakdown";
        Set<CoupletMsgData> members = redisService.getCacheSet(key);
        if (members.size()>0){
            for (CoupletMsgData member : members) {
                Set<String> breakdownIds = redisService.getCacheSet(member.getVin()+":"+key);
                if (breakdownIds.size()==0){
                    CompletableFuture.runAsync(() -> {
                    CoupletTroubleCode troubleCode = new CoupletTroubleCode();
                    troubleCode.setTroubleStartTime(new Date());
                    troubleCode.setTroubleVin(member.getVin());
                    // 随机生成故障码
                    String faultCode = MsgUtils.generateGTA();
                    troubleCode.setTroubleCode(faultCode);

                        switch (member.getVehicleStatus()) {
                            case 0:
                                troubleCode.setTroublePosition("190");
                                troubleCode.setProcessingState(0);
                                break;
                            default:
                                switch (member.getChargingStatus()) {
                                    case 0:
                                        troubleCode.setTroublePosition("191");
                                        troubleCode.setProcessingState(0);
                                        break;
                                    default:
                                        switch (member.getOperatingStatus()) {
                                            case 0:
                                                troubleCode.setTroublePosition("192");
                                                troubleCode.setProcessingState(0);
                                                break;
                                            default:
                                                switch (member.getSocStatus()) {
                                                    case 0:
                                                        troubleCode.setTroublePosition("193");
                                                        troubleCode.setProcessingState(0);
                                                        break;
                                                    default:
                                                        switch (member.getChargingEnergyStorageStatus()) {
                                                            case 0:
                                                                troubleCode.setTroublePosition("194");
                                                                troubleCode.setProcessingState(0);
                                                                break;
                                                            default:
                                                                switch (member.getDriveMotorStatus()) {
                                                                    case 0:
                                                                        troubleCode.setTroublePosition("195");
                                                                        troubleCode.setProcessingState(0);
                                                                        break;
                                                                    default:
                                                                        switch (member.getPositionStatus()) {
                                                                            case 0:
                                                                                troubleCode.setTroublePosition("196");
                                                                                troubleCode.setProcessingState(0);
                                                                                break;
                                                                            default:
                                                                                switch (member.getEasStatus()) {
                                                                                    case 0:
                                                                                        troubleCode.setTroublePosition("197");
                                                                                        troubleCode.setProcessingState(0);
                                                                                        break;
                                                                                    default:
                                                                                        switch (member.getPtcStatus()) {
                                                                                            case 0:
                                                                                                troubleCode.setTroublePosition("198");
                                                                                                troubleCode.setProcessingState(0);
                                                                                                break;
                                                                                            default:
                                                                                                switch (member.getEpsStatus()) {
                                                                                                    case 0:
                                                                                                        troubleCode.setTroublePosition("199");
                                                                                                        troubleCode.setProcessingState(0);
                                                                                                        break;
                                                                                                    default:
                                                                                                        switch (member.getAbsStatus()) {
                                                                                                            case 0:
                                                                                                                troubleCode.setTroublePosition("200");
                                                                                                                troubleCode.setProcessingState(0);
                                                                                                                break;
                                                                                                            default:
                                                                                                                switch (member.getMcuStatus()) {
                                                                                                                    case 0:
                                                                                                                        troubleCode.setTroublePosition("201");
                                                                                                                        troubleCode.setProcessingState(0);
                                                                                                                        break;
                                                                                                                    default:
                                                                                                                        switch (member.getHeatingStatus()) {
                                                                                                                            case 0:
                                                                                                                                troubleCode.setTroublePosition("202");
                                                                                                                                troubleCode.setProcessingState(0);
                                                                                                                                break;
                                                                                                                            default:
                                                                                                                                switch (member.getBatteryStatus()) {
                                                                                                                                    case 0:
                                                                                                                                        troubleCode.setTroublePosition("203");
                                                                                                                                        troubleCode.setProcessingState(0);
                                                                                                                                        break;
                                                                                                                                    default:
                                                                                                                                        switch (member.getBatteryInsulationStatus()) {
                                                                                                                                            case 0:
                                                                                                                                                troubleCode.setTroublePosition("204");
                                                                                                                                                troubleCode.setProcessingState(0);
                                                                                                                                                break;
                                                                                                                                            default:
                                                                                                                                                switch (member.getDcdcStatus()) {
                                                                                                                                                    case 0:
                                                                                                                                                        troubleCode.setTroublePosition("205");
                                                                                                                                                        troubleCode.setProcessingState(0);
                                                                                                                                                        break;
                                                                                                                                                    default:
                                                                                                                                                        switch (member.getChgStatus()) {
                                                                                                                                                            case 0:
                                                                                                                                                                troubleCode.setTroublePosition("206");
                                                                                                                                                                troubleCode.setProcessingState(0);
                                                                                                                                                                break;
                                                                                                                                                            default:
                                                                                                                                                                // do nothing
                                                                                                                                                                break;
                                                                                                                                                        }
                                                                                                                                                        break;
                                                                                                                                                }
                                                                                                                                                break;
                                                                                                                                        }
                                                                                                                                        break;
                                                                                                                                }
                                                                                                                                break;
                                                                                                                        }
                                                                                                                        break;
                                                                                                                }
                                                                                                                break;
                                                                                                        }
                                                                                                        break;
                                                                                                }
                                                                                                break;
                                                                                        }
                                                                                        break;
                                                                                }
                                                                                break;
                                                                        }
                                                                        break;
                                                                }
                                                                break;
                                                        }
                                                        break;
                                                }
                                                break;
                                        }
                                        break;
                                }
                                break;
                        }
                    remoteTroubleService.newFaultData(troubleCode);
                });
                    redisService.setCacheSet(member.getVin()+":"+key, member.getVin()+":"+member);
                    long expireTime = 30;
                    redisService.expire(member.getVin()+":"+key, expireTime, TimeUnit.MINUTES);
                }
            }

        }

    }
}
