package com.couplet.analyze.msg.service.impl;

import com.alibaba.fastjson.JSON;
import com.couplet.analyze.common.contents.AnalyzeEventContents;
import com.couplet.analyze.msg.domain.CoupletMsgData;
import com.couplet.analyze.msg.service.IncidentService;
import com.couplet.common.core.text.Convert;
import com.couplet.common.domain.Fence;
import com.couplet.common.domain.request.FenceAndLogeRequest;
import com.couplet.common.redis.service.RedisService;
import com.couplet.remote.RemoteFenceAndLogService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * @Author: LiJiaYao
 * @Date: 2024/4/2
 * @Description: 电子围栏事件服务实现类
 */
@Service(AnalyzeEventContents.ELECTRONIC_FENCE)
@Log4j2
public class ElectronicFenceServiceImpl implements IncidentService {

    @Autowired
    private RedisService redisService;
    @Autowired
    private RemoteFenceAndLogService remoteFenceAndLogService;

    /**
     * 电子围栏事件
     *
     * @param coupletMsgData
     */
    @Override
    public void incident(CoupletMsgData coupletMsgData) {

        log.info("电子围栏事件开始.......");

        String fenceKey = "车辆vin和电子围栏:" + coupletMsgData.getVin();
        if (redisService.hasKey(fenceKey)) {
            Set<Fence> cacheSet = redisService.getCacheSet(fenceKey);
            log.info("电子围栏事件redis存在.......");
//            jingdu;
//            longitude;
//            weidu;
//            latitude;
            for (Fence fence : cacheSet) {
                String fenceLongitudeLatitude = fence.getFenceLongitudeLatitude();
                /**
                 * 先通过；后切割
                 */
                String[] split = fenceLongitudeLatitude.split(";");
                for (String s : split) {
                    String[] strings = s.split(",");
                    if (strings.length == 2) {
                        // 经度
                        Double trim = Double.valueOf(strings[0].trim());
                        // 纬度
                        Double trim1 = Double.valueOf(strings[1].trim());
                        boolean a = trim <= Double.valueOf(coupletMsgData.getLongitude());
                        boolean b = trim1 <= Double.valueOf(coupletMsgData.getLatitude());
                        if (a && b) {
                            log.info("电子围栏报警啦!!!!您的车驶出范围啦!!!");
                        } else {
                            log.info("电子围栏报警啦!!!!正常啦!!!");
                        }
                        log.info("经度是:" + trim);
                        log.info("纬度是:" + trim1);
                    } else {
                        throw new RuntimeException("电子围栏经纬度格式错误" + strings);
                    }
                }
            }
            log.info("电子围栏事件结束.......");
        }
        log.info("电子围栏事件结束.......");
    }

    /**
     * @return 电子围栏service 名称
     */
    @Override
    public String getName() {
        return AnalyzeEventContents.ELECTRONIC_FENCE;
    }


    public void ifFence() {
        String key = "id";
        /**
         * redisService中的object类型获取到数据
         */
        String cacheObject = redisService.getCacheObject(key);
        String[] split = cacheObject.split("-");
        Long id = Convert.toLong(split[0]);
        Long[] longArray = Convert.toLongArray(split[1]);
//        for (Long aLong : longArray) {
//            aLong.wait(",");
//        }
        FenceAndLogeRequest fenceAndLogeRequest = new FenceAndLogeRequest();
        fenceAndLogeRequest.setId(id);
        fenceAndLogeRequest.setLogoIds(longArray);
        remoteFenceAndLogService.queryByFenceAndLogoIds(fenceAndLogeRequest);

    }

}
