package com.couplet.analyze.msg.service.impl;

import com.couplet.analyze.common.contents.AnalyzeEventContents;
import com.couplet.analyze.msg.domain.CoupletMsgData;
import com.couplet.analyze.msg.mapper.IncidentMapper;
import com.couplet.analyze.msg.service.IncidentService;
import com.couplet.analyze.msg.service.impl.realTimeData.RealTimeJudge;
import com.couplet.common.domain.request.RealTimeDataRequest;
import com.couplet.common.redis.service.RedisService;
import com.couplet.remote.RemoteRealTimeService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.concurrent.TimeUnit;

/**
 * @Author: LiJiaYao
 * @Date: 2024/4/2
 * @Description: 实时数据事件
 */
@Service(AnalyzeEventContents.REAL_TIME_DATA)
@Log4j2
public class RealTimeDataServiceImpl implements IncidentService {

    /**
     * 查询传入的数据是否存在
     */
    @Autowired
    private IncidentMapper incidentMapper;

    @Autowired
    private RedisService redisService;

    /**
     * 实时数据事件
     *
     * @param coupletMsgData
     */
    @Override
    public void incident(CoupletMsgData coupletMsgData) {
        log.info("实时数据事件开始.....");
        RealTimeDataRequest cacheObject = redisService.getCacheObject("vin:" + coupletMsgData.getVin());
//        //判断是否有缓存数据
//        if (redisService.hasKey("vin:query:" + coupletMsgData.getVin())){
//            redisService.deleteObject("vin:query:" + coupletMsgData.getVin());
//        }
//         if (RealTimeJudge.isJudge(coupletMsgData.getVin())) {
        if (coupletMsgData.getVin().equals(cacheObject.getVin())){
//            log.info("有实时数据，值为：[{}]开始传输实时数据", coupletMsgData.getVin());
             //判断数据是否一致，
//             if (RealTimeJudge.addRealTime(cacheObject)) {
                 log.info("[{}]有缓存数据，值为：[{}]，且缓存数据与实时数据一致，开始传输实时数据", coupletMsgData.getVin(), cacheObject);
                 redisService.setCacheSet("vin:query:" + coupletMsgData.getVin(), coupletMsgData);
                 redisService.expire("vin:"+coupletMsgData.getVin(),10, TimeUnit.MINUTES);
//             } else {
//                 log.info("[{}]有缓存数据，值为：[{}]，且缓存数据与实时数据不一致，开始传输实时数据", coupletMsgData.getVin(), cacheObject);
//             }
        }

        log.info("[{}]开始传输实时数据", coupletMsgData.getVin());

        log.info("实时数据事件结束.....");

    }

    /**
     * 实时数据事件
     *
     * @return
     */
    @Override
    public String getName() {
        return AnalyzeEventContents.REAL_TIME_DATA;
    }
}
