package com.couplet.business.server.controller;

import com.couplet.business.server.service.VehicleAndLogoService;
import com.couplet.common.core.domain.Result;
import com.couplet.common.core.web.controller.BaseController;
import com.couplet.common.log.annotation.Log;
import com.couplet.common.log.enums.BusinessType;
import com.couplet.common.security.annotation.RequiresPermissions;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @Author: LiJiaYao
 * @Date: 2024/4/7
 * @Description: 车辆和标识中间信息
 */
@RestController
@Log4j2
@RequestMapping("/vehicleAndLogo")
public class VehicleAndLogoController extends BaseController {

    /**
     * 调用车辆logo接口
     */
    @Autowired
    private VehicleAndLogoService vehicleAndLogoService;

    /**
     * 根据车辆id查询绑定的标识
     * @param vehicleId
     * @return
     */
    @Log(title = "查询车辆id绑定的标识", businessType = BusinessType.OTHER)
    @PostMapping("/queryByLogoIds/{vehicleId}")
    public Result<?> queryByLogoIds(@PathVariable("vehicleId") Long vehicleId){
        List<Long> bindLogoById = vehicleAndLogoService.getBindLogoById(vehicleId);
        return success(bindLogoById);
    }

}
