package com.couplet.business.server.controller;

import com.couplet.analyze.msg.domain.CoupletMsgData;
import com.couplet.business.server.service.VehicleDetectionService;
import com.couplet.common.core.domain.Result;
import com.couplet.common.domain.CoupletVehicleData;
import com.couplet.common.domain.Vehicle;
import com.couplet.common.domain.request.RealTimeDataRequest;
import com.couplet.common.redis.service.RedisService;
import com.couplet.common.security.utils.SecurityUtils;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Objects;

/**
 * @author fufanrui
 * @version 1.0
 * @description: 车辆检测控制器
 * @date 2024/4/4 10:11
 */

@RestController
@RequestMapping("detection")
public class VehicleDetectionController {

    @Autowired
    private VehicleDetectionService vehicleDetectionService;
    @Autowired
    private RabbitTemplate rabbitTemplate;
    @Autowired
    private RedisService redisService;
    private final String REDIS_LIST_KEY = "coupletMsgData";
    /*
     * @param :
      * @return Result<List<Vehicle>>
     * @author 付凡芮
     * @description 查询上线的车辆信息
     * @date
     */
    @PostMapping("/detectionList")
    public Result<List<Vehicle>> detectionList() {
        return Result.success(vehicleDetectionService.detectionList());
    }


    /*
     * @param vin:
     * @return Result<List<Vehicle>>
     * @author 付凡芮
     * @description 根据vin查询车辆信息
     * @date
     */
    @PostMapping("/monitorinData/{vin}")
    public void monitorinData(@PathVariable String vin){
        vehicleDetectionService.monitorinData(vin);
    }
    /*
     * @param :
     * @return Result<List<CoupletVehicleData>>
     * @author 付凡芮
     * @description 查看事实数据列表
     * @date
     */
    @PostMapping("/monitorinDataList/{vin}")
    public Result<List<CoupletMsgData>> monitorinDataList(@PathVariable String vin){
        List<CoupletMsgData> monitorinDataList  =  vehicleDetectionService.monitorinDataList(vin);
        Result<List<CoupletMsgData>> success = Result.success(monitorinDataList);
        return success;
    }


    /*
     * @param vin:
      * @return void
     * @author 付凡芮
     * @description 停止传送实时数据
     * @date
     */
    @PostMapping("stopViewingData/{vin}")
    public void stopViewingData(@PathVariable String vin){
        vehicleDetectionService.stopViewingData(vin);
    }

}
