package com.couplet.business.server.service.impl;

import afu.org.checkerframework.checker.units.qual.A;
import com.alibaba.fastjson.JSON;
import com.couplet.analyze.msg.domain.CoupletMsgData;
import com.couplet.analyze.common.event.AnalyzeEventCache;
import com.couplet.business.server.mapper.VehicleDetectionMapper;
import com.couplet.business.server.service.VehicleDetectionService;
import com.couplet.business.server.service.VehicleManageService;
import com.couplet.common.core.domain.Result;
import com.couplet.common.domain.CoupletVehicleData;
import com.couplet.common.domain.Vehicle;
import com.couplet.common.domain.request.RealTimeDataRequest;
import com.couplet.common.redis.service.RedisService;
import com.couplet.common.security.utils.SecurityUtils;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.mysql.cj.xdevapi.JsonString;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import springfox.documentation.spring.web.json.Json;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.TimeUnit;

/**
 * @author fufanrui
 * @version 1.0
 * @description: 车辆检测服务实现类
 * @date 2024/4/4 10:23
 */
@Service
@Slf4j
public class VehicleDetectionServiceImpl implements VehicleDetectionService{

    @Autowired
    private VehicleDetectionMapper vehicleDetectionMapper;
    @Autowired
    private RedisService redisService;
    @Autowired
    private AnalyzeEventCache analyzeEventCache;

    @Override
    public List<Vehicle> detectionList() {
        List<Vehicle> vehicles = vehicleDetectionMapper.detectionList();

        return vehicles;
    }

    @Override
    public List<CoupletMsgData> monitorinDataList(String vin) {
        String key = "vin:query:" + vin;
        log.info("key为:"+key);
        CoupletMsgData coupletMsgData = redisService.getCacheObject(key);
        ArrayList<CoupletMsgData> coupletMsgDataArrayList = new ArrayList<>();
        coupletMsgDataArrayList.add(coupletMsgData);
        return coupletMsgDataArrayList;
    }

    @Override
    public void monitorinData(String vin) {
        RealTimeDataRequest realTimeDataRequest = new RealTimeDataRequest();
        Long userId = SecurityUtils.getUserId();
        realTimeDataRequest.setVin(vin);
        realTimeDataRequest.setUserId(userId);
//        analyzeEventCache.queryEvent("查询实时数据"+vin,realTimeDataRequest);
//        redisService.expire("查询实时数据"+vin,4,TimeUnit.MINUTES);
        redisService.setVinAndUserId(realTimeDataRequest);
    }

    @Override
    public void stopViewingData(String vin) {
        redisService.stopViewingData(vin);
    }


}
